@@ -30,14 +30,13 @@ class DrKonqi
 {
 public:
     static bool init();
-    static void cleanup();
 
     static SystemInformation *systemInformation();
     static DebuggerManager *debuggerManager();
     static CrashedApplication *crashedApplication();
 
     static void saveReport(const QString & reportText, QWidget *parent = nullptr);
-
+    static void shutdownSaveReport();
     static void setSignal(int signal);
     static void setAppName(const QString &appName);
     static void setAppPath(const QString &appPath);
