@@ -24,7 +24,6 @@
 #include "drkonqi_parser_debug.h"
 #include <QRegExp>
 #include <QMetaEnum>
-#include <QDebug>
 
 //factory
 BacktraceParser *BacktraceParser::newParser(const QString & debuggerName, QObject *parent)
@@ -199,18 +198,18 @@ static bool lineIsStackTop(const BacktraceLine & line)
    for some reason. Currently it ignores all libc/libstdc++/libpthread functions. */
 static bool lineShouldBeIgnored(const BacktraceLine & line)
 {
-    if ( line.libraryName().contains(QStringLiteral("libc.so"))
-        || line.libraryName().contains(QStringLiteral("libstdc++.so"))
+    if ( line.libraryName().contains(QLatin1String("libc.so"))
+        || line.libraryName().contains(QLatin1String("libstdc++.so"))
         || line.functionName().startsWith(QLatin1String("*__GI_")) //glibc2.9 uses *__GI_ as prefix
-        || line.libraryName().contains(QStringLiteral("libpthread.so"))
-        || line.libraryName().contains(QStringLiteral("libglib-2.0.so"))
+        || line.libraryName().contains(QLatin1String("libpthread.so"))
+        || line.libraryName().contains(QLatin1String("libglib-2.0.so"))
 #ifdef Q_OS_MACOS
-        || (line.libraryName().startsWith(QStringLiteral("libsystem_")) && line.libraryName().endsWith(QStringLiteral(".dylib")))
-        || line.libraryName().contains(QStringLiteral("Foundation`"))
+        || (line.libraryName().startsWith(QLatin1String("libsystem_")) && line.libraryName().endsWith(QLatin1String(".dylib")))
+        || line.libraryName().contains(QLatin1String("Foundation`"))
 #endif
-        || line.libraryName().contains(QStringLiteral("ntdll.dll"))
-        || line.libraryName().contains(QStringLiteral("kernel32.dll"))
-        || line.functionName().contains(QStringLiteral("_tmain"))
+        || line.libraryName().contains(QLatin1String("ntdll.dll"))
+        || line.libraryName().contains(QLatin1String("kernel32.dll"))
+        || line.functionName().contains(QLatin1String("_tmain"))
         || line.functionName() == QLatin1String("WinMain") )
         return true;
 
