@@ -1,6 +1,7 @@
 /*******************************************************************
 * systeminformation.h
 * Copyright 2009    Dario Andres Rodriguez <andresbajotierra@gmail.com>
+* Copyright 2019    Harald Sitter <sitter@kde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
@@ -26,7 +27,20 @@ class SystemInformation: public QObject
 {
     Q_OBJECT
     public:
-        explicit SystemInformation(QObject * parent = nullptr);
+        struct Config {
+            Config();
+
+            // Overrides m_operatingSystem value
+            QString basicOperatingSystem;
+            // Path to lsb_release executable
+            QString lsbReleasePath;
+            // Path to os-release file
+            QString osReleasePath;
+            // Function pointer to uname override
+            void *unameFunc = nullptr;
+        };
+
+        explicit SystemInformation(Config infoConfig = Config(), QObject * parent = nullptr);
         ~SystemInformation() override;
 
         QString bugzillaPlatform() const;
@@ -35,7 +49,7 @@ class SystemInformation: public QObject
         QString operatingSystem() const;
         QString bugzillaOperatingSystem() const;
 
-        QString lsbRelease() const;
+        QString distributionPrettyName() const;
 
         bool compiledSources() const;
         void setCompiledSources(bool);
@@ -43,13 +57,15 @@ class SystemInformation: public QObject
         QString qtVersion() const;
         QString frameworksVersion() const;
 
+        /// All helpers finished and the data is complete
+        bool complete() const;
+
     private Q_SLOTS:
         void lsbReleaseFinished();
 
     private:
-        QString fetchOSBasicInformation() const;
         QString fetchOSDetailInformation() const;
-        QString fetchOSReleaseInformation() const;
+        QString fetchOSReleaseInformation();
 
         QString guessBugzillaPlatform(const QString&) const;
 
@@ -60,9 +76,13 @@ class SystemInformation: public QObject
         QString     m_bugzillaOperatingSystem;
         QString     m_bugzillaPlatform;
 
-        QString     m_lsbRelease;
+        QString     m_distributionPrettyName;
 
         bool        m_compiledSources;
+
+        bool m_complete; // all available data retrieved
+
+        Config m_infoConfig;
 };
 
 #endif
